<?php

require_once(dirname(__FILE__) . '/../componenthelper.inc.php');

// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication();

// grab all of the host data
$args1 = array();
$gethosts = get_xml_host_objects($args1);

$args2 = array();
$gethoststatus = get_xml_host_status($args2);

$args3 = array();
$getparenthosts = get_xml_host_parents($args3);

$hostArray = array();
$hostLatLng = array();
$relationshipArray = array();
$markers = array();
$LatLngArray = array();
$markerDataArray = array();


// loop for host objects
foreach ($gethosts->children() as $this_host)
{
    if ((isset($this_host->host_name) && isset($this_host->notes))) 
    {
        $hostArray["{$this_host['id']}"]["host_name"] = $this_host->host_name; //security fix
        $hostArray["{$this_host['id']}"]["notes"] = $this_host->notes;
        $hostArray["{$this_host['id']}"]["host_id"] = $this_host["id"];
    }
}


// loop for host statuses
foreach ($gethoststatus->children() as $status) 
{

    if (strlen($status->name) > 2) //this xml array had empty variables that were set, needed a workaround
    {
        switch ($status->current_state) //grab current host state and assign a balloon icon
        {
            case 0:
                $icon = 'https://www.google.com/mapfiles/marker_green.png'; //host is up
                break;
            case 1:
                $icon = 'https://www.google.com/mapfiles/marker.png'; //host is critical
                break;
            case 2:
                $icon = 'https://www.google.com/mapfiles/marker.png'; //host is something else not good
                break;
            default:
                $icon = 'https://www.google.com/mapfiles/marker_white.png'; //set for any other unknown cases
                break;
        }

        $hostArray["{$status->host_id}"]["icon"] = $icon; //grab status_text field from xml data
        $hostArray["{$status->host_id}"]["status_text"] = $status->status_text;
        $hostArray["{$status->host_id}"]["current_state"] = $status->current_state;
    }
}


// $hostdata is the actual host array
foreach ($hostArray as $hostdata) 
{

    if (this_host_matches_host_and_hostgroup_filters($host, $hostgroup, (string)$hostdata['host_name'])) 
    {

        // validate the note data
        $parts = explode(',', $hostdata['notes']);
        if (empty($parts) || !floatval($parts[0]) || !isset($parts[1]) || !floatval($parts[1])) {
            continue;
        }

        // only use arrays with all 3 good variables
        if (strlen($hostdata["notes"]) > 6 && isset($hostdata["icon"])) {

            $LatLng = str_replace(" ", "", $hostdata['notes']);

            // if this latlng is already in our array, then we need to append the marker data instead of create a new one
            if (in_array($LatLng, $LatLngArray)) {

                // append to the marker title
                $markerDataArray[$LatLng]['marker_title'] .= " - " . $hostdata['host_name'];

                // check to see if our current state is higher than whats on record, and update accordingly
                if (intval($hostdata['current_state']) > intval($markerDataArray[$LatLng]['current_state'])) {
                    $markerDataArray[$LatLng]['marker_icon'] = $hostdata['icon'];
                }

                // append to the info window data so it can all be aggregated later
                $markerDataArray[$LatLng]['info_window_data'] .= 
                    "+'" . '<h2 id="firstHeading" class="firstHeading">' . $hostdata['host_name'] . "</h2>" .
                    '<div id="bodyContent">' .
                        "<p>" . $hostdata['status_text'] . "</p>" . 
                        '<p>' . 
                            '<a href="../xicore/status.php?show=hostdetail&host=' . $hostdata['host_name'] . '">' .
                                $hostdata['host_name'] . " Details" . 
                            "</a>" .
                        "</p>" .
                    "</div>'";

            } 

            // if this latlng is not in the latlngarray, we just create the marker and then add 
            else {

                // build the markerDataArray
                $markerDataArray[$LatLng] = array(
                    'current_state'         => $hostdata['current_state'],
                    'lat_lng'               => "latLng_{$hostdata['host_id']}",
                    'marker_title'          => $hostdata['host_name'],
                    'marker_icon'           => $hostdata['icon'],
                    'marker_id'             => "marker_{$hostdata['host_id']}",
                    'marker_position'       => "latLng_{$hostdata['host_id']}", 
                    'info_window_data'      => 
                        "'" . '<h2 id="firstHeading" class="firstHeading">' . $hostdata['host_name'] . "</h2>" .
                        '<div id="bodyContent">' .
                            "<p>" . $hostdata['status_text'] . "</p>" . 
                            "<p>" .
                                '<a href="../xicore/status.php?show=hostdetail&host=' . $hostdata['host_name'] . '">' .
                                    $hostdata['host_name'] . " Details" .
                                "</a>" .
                            "</p>" .
                        "</div>'",
                );
                $LatLngArray[] = $LatLng;

            } // end if in_array(latlng,latlngarray)

            // we add this no matter what so that the parent/child relationship lines work
            $markers[] = $hostdata['host_id'];
            echo "latLng_{$hostdata['host_id']} = new google.maps.LatLng({$hostdata['notes']});";

        } // end of if for strlen>6 && icon
    } // end of filter host/hostgroup if
} // end of marker FOREACH

// cycle back through the markerDataArray and echo out our javascript
foreach($markerDataArray as $markerData) {

    echo <<<MARKERDATA

    {$markerData['lat_lng']}

    {$markerData['marker_id']} = new google.maps.Marker({
        position:   {$markerData['marker_position']},
        title:      "{$markerData['marker_title']}",
        icon:       "{$markerData['marker_icon']}",
        map:        map
    });

    google.maps.event.addListener({$markerData['marker_id']}, 'click', function() {
        if (infowindow) {
            infowindow.close();
        }
        contentString = '<div id="content"><div id="siteNotice"></div>' + {$markerData['info_window_data']} + '</div>';

        infowindow = new google.maps.InfoWindow({ content: contentString });
        infowindow.open(map, {$markerData['marker_id']});
    });

MARKERDATA;

}


// loop for parent hosts
$show_polylines = "";
$hide_polylines = "";

// if hide lines is set, then we don't draw the lines
$polyline_map = "map";
if ($hide_lines) {
    $polyline_map = "null";
}

$linecolor = (isset($linecolor) && !empty($linecolor)) ? htmlentities($linecolor) : '#ee1212';
foreach ($getparenthosts->children() as $parenthost)
{

    if (   strlen($parenthost->host_name) > 2 
        && isset($hostArray["{$parenthost->host_id}"]["notes"]) 
        && isset($hostArray["{$parenthost->parent_host_id}"]["notes"]) 
        && in_array("$parenthost->host_id", $markers) 
        && in_array("$parenthost->parent_host_id", $markers)) { 

        echo "
            var l_{$parenthost->host_id}_to_{$parenthost->parent_host_id} = new google.maps.Polyline({
                path: [ latLng_{$parenthost->host_id} , latLng_{$parenthost->parent_host_id} ],
                strokeColor: \"{$linecolor}\",
                strokeOpacity: 0.9,
                strokeWeight: 2        
            });
            l_{$parenthost->host_id}_to_{$parenthost->parent_host_id}.setMap({$polyline_map});
            ";

        // build javascript for hiding and showing polylines
        $show_polylines .= "l_{$parenthost->host_id}_to_{$parenthost->parent_host_id}.setMap(map);\n";
        $hide_polylines .= "l_{$parenthost->host_id}_to_{$parenthost->parent_host_id}.setMap(null);\n";

    }
}

// showing and hiding polylines!
echo "
    $('#hide_lines').click(function() {
        if ($(this).is(':checked')) {
            {$hide_polylines}
        } else {
            {$show_polylines}
        }
    });
";

// function will return true based on if it matches filtered critera
function this_host_matches_host_and_hostgroup_filters($request_host, $request_hostgroup, $host_to_check) {

    if (!empty($request_host)) {
        if ($request_host == $host_to_check) {
            return true;
        }
    }

    if (!empty($request_hostgroup)) {
        if (is_host_member_of_hostgroup($host_to_check, $request_hostgroup)) {
            return true;
        }
    }

    if (empty($request_host) && empty($request_hostgroup)) {
        return true;
    }

    return false;
}
?>
