<?php
//
// Google Map Component
// Copyright (c) 2010-2018 Nagios Enterprises, LLC. All rights reserved.
//

require_once(dirname(__FILE__) . '/../componenthelper.inc.php');

$googlemap_component_name = "googlemap";
googlemap_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function googlemap_component_init()
{
    global $googlemap_component_name;

    $versionok = googlemap_component_checkversion();

    $desc = "";
    if (!$versionok) {
        $desc = "<b>" . _("Error: This component requires Nagios XI 2009R1.2B or later.") . "</b>";
    }

    $args = array(
        COMPONENT_NAME        => $googlemap_component_name,
        COMPONENT_AUTHOR      => "Nagios Enterprises, LLC",
        COMPONENT_DESCRIPTION => _("Adds a google map to the maps menu where hosts with defined coordinates can be viewed. ") . $desc,
        COMPONENT_TITLE       => _("Google Map"),
        COMPONENT_VERSION     => "1.6.2",
        COMPONENT_DATE        => "05/20/2019",
        COMPONENT_CONFIGFUNCTION => 'gmaps_component_config_func',
    );

    register_component($googlemap_component_name, $args);

    // add a menu link
    if ($versionok) {
        register_callback(CALLBACK_MENUS_INITIALIZED, 'googlemap_component_addmenu');
    }
}


///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function googlemap_component_checkversion()
{

    if (!function_exists('get_product_release')) {
        return false;
    }

    //requires greater than 2009R1.2
    if (get_product_release() < 114) {
        return false;
    }

    return true;
}

function googlemap_component_addmenu($arg = null)
{
    global $googlemap_component_name;

    $urlbase = get_component_url_base($googlemap_component_name);

    if (get_product_release() < 5600) {
        $mi = find_menu_item(MENU_HOME, "menu-home-networkstatusmap", "id");
    } else {
        $mi = find_menu_item(MENU_HOME, "menu-home-section-maps", "id");
    }
    if ($mi == null) {
        return;
    }

    $order = grab_array_var($mi, "order", "");
    if ($order == "") {
        return;
    }

    if (get_product_release() < 5600) {
        $neworder = $order - 0.1;
    } else {
        $neworder = $order + 0.5;
    }

    add_menu_item(MENU_HOME, array(
        "type"     => "link",
        "title"    => _("Google Map"),
        "id"       => "menu-home-googlemap",
        "order"    => $neworder,
        "opts"     => array(
            "href"      => $urlbase . "/map.php",
        )
    ));

}

function gmaps_component_config_func($mode = "", $inargs, &$outargs, &$result){
    global $googlemap_component_name;

    $result = 0;
    $output = "";

    $component_name = $googlemap_component_name;

    switch ($mode) {
        case COMPONENT_CONFIGMODE_GETSETTINGSHTML:

            $settings_raw = get_option("googlemap_options");
            if ($settings_raw == "")
                $settings = array();
            else
                $settings = unserialize($settings_raw);

            // initial values
            $api_key = grab_array_var($settings, "api_key", "");

            // values passed to us
            $api_key = grab_array_var($inargs, "api_key", $api_key);

            $component_url = get_component_url_base($component_name);

            $output = '            
<h5 class="ul">' . _('Google Maps Settings') . '</h5>

<table class="table table-condensed table-no-border table-auto-width">

    <tr>
        <td class="vt">
            <label>' . _('API Key') . ':</label>
        </td>
        <td>
            <input type="text" size="25" name="api_key" id="api_key" value="' . htmlentities($api_key) . '" class="form-control">
            <div class="subtext">' . _('Your Google maps API key') . '.</div>
        </td>
    </tr>
</table>';

            break;

        case COMPONENT_CONFIGMODE_SAVESETTINGS:

            // get variables
            $api_key = grab_array_var($inargs, "api_key", "");

            // validate variables
            $errors = 0;
            $errmsg = array();
            if ($enabled == 1) {
                if (have_value($api_key) == false) {
                    $errmsg[$errors++] = _("No API key specified.");
                }
            }

            // handle errors
            if ($errors > 0) {
                $outargs[COMPONENT_ERROR_MESSAGES] = $errmsg;
                $result = 1;
                return '';
            }

            // save settings
            $settings = array(
                "api_key" => $api_key,
            );
            set_option("googlemap_options", serialize($settings));

            break;

        default:
            break;

    }

    return $output;
}

?>