<?php
//
// Google Map Component
// Copyright (c) 2008-2018 Nagios Enterprises, LLC. All rights reserved.
//

require_once(dirname(__FILE__) . '/../componenthelper.inc.php');

// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication();


// route request
route_request();


function route_request()
{
    global $request;

    show_page();

    exit;
}


function show_page($error = false, $msg = "")
{
    global $request;
    global $lstr;


    $settings_raw = get_option("googlemap_options");
    if ($settings_raw == "")
        $settings = array();
    else
        $settings = unserialize($settings_raw);

    // initial values
    $api_key = grab_array_var($settings, "api_key", "");
    
    //do_page_start(array("page_title"=>"Google Map"),true);

    ?>

<!DOCTYPE html>
<html>
    <!-- Produced by Nagios XI.  Copyright (c) 2008-2018 Nagios Enterprises, LLC (www.nagios.com). All Rights Reserved. -->

    <head>
        <title>Nagios XI - Google Map</title>
        <meta name="viewport" content="initial-scale=1.0, user-scalable=no"/>
        <meta name="ROBOTS" content="NOINDEX, NOFOLLOW">
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
        <?php
        do_page_head_links();
        ?>

<style type="text/css">
html {
    height: 100%
}

body {
    height: 95%;
    margin: 0px;
    padding: 0px
}

#map_canvas {
    height: 90%
}

a {
    padding-right: 10px;
}

div.formdiv {
    padding: 5px;
}
</style>

<!--Replace below line with google's premier client ID script for appropriate commercial use-->
<?php
    if (!empty($api_key)){
        echo '<script type="text/javascript" src="https://maps.google.com/maps/api/js?key=' . $api_key . '"></script>';
    } else {
        echo '<script type="text/javascript" src="https://maps.google.com/maps/api/js"></script>';
    }

    /* get any filter variables */
    $host = grab_request_var('host', '');
    $hostgroup = grab_request_var('hostgroup', '');
    $hide_lines = grab_request_var('hide_lines', 0);
    $hide_lines_checked = "";
    if ($hide_lines)
        $hide_lines_checked = " checked=\"checked\" ";

    $coords = get_user_meta($_SESSION["user_id"], 'googlemap_coords', get_option('googlemap_coords', '37.09024, -95.71289'));
    $zoom = get_user_meta($_SESSION["user_id"], 'googlemap_zoom', get_option('googlemap_zoom', 5));
    $refresh = get_user_meta($_SESSION["user_id"], 'googlemap_refresh', 30);
    $maptypeid = "google.maps.MapTypeId.HYBRID";
    $linecolor = get_user_meta($_SESSION["user_id"], 'googlemap_linecolor', '#ee1212');

    if (isset($_GET['coords']) && !empty($_GET['coords'])) {
        $coords = $_GET['coords'];
        /* this is converted from a LatLng.toString() which does some weird things, so we need to account for that */
        $coords = str_replace(array("(", ")", " "), "", $coords);
    }
    if (isset($_GET['zoom']) && !empty($_GET['zoom'])) {
        $zoom = $_GET['zoom'];
    }
    if (isset($_GET['maptypeid']) && !empty($_GET['maptypeid'])) {
        $maptypeid = "google.maps.MapTypeId." . str_replace("GOOGLE.MAPS.MAPTYPEID.", "", strtoupper($_GET['maptypeid']));
    }
?>

<script type="text/javascript">
    var infowindow;
    var map = false;
    function initialize() {

        /*set initial map center coordinates */
        /* value must be numeric */
        var defZoom = <?php print htmlentities($zoom); ?>;

        /* must be the google latlng object */
        var myLatlng = new google.maps.LatLng(<?php print htmlentities($coords); ?>);

        /*create the map */
        if (myLatlng) {

            /*set map defaults */
            var myOptions = {
                zoom: defZoom,
                center: myLatlng,
                minZoom: 2,
                maxZoom: 20,
                mapTypeId: <?php echo $maptypeid; ?>
            }

            if(!map) {
                map = new google.maps.Map(document.getElementById("map_canvas"), myOptions);
            }

            /* set up some listeners for zoom/center changes so we can track it across page reloads */
            map.addListener('center_changed', function() {
                document.getElementById('reload_form_coords').value = map.getCenter().toString();
            });
            map.addListener('zoom_changed', function() {
                document.getElementById('reload_form_zoom').value = map.getZoom();
            });
            map.addListener('maptypeid_changed', function() {
                document.getElementById('reload_form_maptypeid').value = map.getMapTypeId();
            });


            /************************ MARKERS ****************************/

            <?php include('buildmarkers.inc.php') ?>

            /********************** END MARKERS **************************/
        }

        /*Sets a default for the googlemap to prevent blank white screen*/
        else
        {
            alert("No default coordinates have been set. Use the 'Reset Map Defaults' to set your default coordinates.");

            /*set map defaults */
            myLatLng1 = new google.maps.LatLng(39.100226, -94.575806);

            var myOptions = {
                zoom: 1,
                center: myLatLng1,
                mapTypeId: google.maps.MapTypeId.HYBRID
            }

            if(!map) {
                var map = new google.maps.Map(document.getElementById("map_canvas"), myOptions);
            }
        }
    }

    var geo;

    /*uses prompt boxes to generate a lat-long coordinate*/
    function geocoder() {

        var address = prompt("<?php echo _("Please enter an address: "); ?>", "");
        geo = new google.maps.Geocoder();

        if (geo) {
            geo.geocode({'address': address}, function (results, status) {

                if (status == google.maps.GeocoderStatus.OK) {
                    var point = results[0].geometry.location.toString();
                    substring = point.substr(1, (point.length - 3));
                    prompt("<?php echo _("Geocode results for your address: "); ?>", substring);
                }

                else {
                    alert("<?php echo _("Geocode was not successful for the following reason: "); ?>" + status);
                }
            });
        }
    }

</script>
    </head>
    <body onload="initialize()">
    <p style="text-align: right;">
        <a href="javascript:void(0)" onclick="geocoder()" title="Geocode An Address">
            <?php echo _("Get Geocode For An Address"); ?>
        </a>
        <a href="set_map_defaults.php">
            <?php echo _("Set Map Defaults"); ?>
        </a>
    </p>

    <div id="map_canvas" style="width:100%; height:90%"></div>

    <div class="formdiv">

        <form id="reload_form" method="get">

            <input type="hidden" name="zoom" id="reload_form_zoom" value="<?php echo $zoom; ?>" />
            <input type="hidden" name="coords" id="reload_form_coords" value="<?php echo $coords; ?>" />
            <input type="hidden" name="maptypeid" id="reload_form_maptypeid" value="<?php echo $maptypeid; ?>" />

            <select name="host" id="reload_form_host" style="width: 150px;" class="form-control">

                <option value=""><?php echo _("Host"); ?>:</option>

                <?php
                    $args = array('orderby' => 'host_name:a');
                    $oxml = get_xml_host_objects($args);
                    if ($oxml) {
                        foreach ($oxml->host as $hostobject) {
                            if (!empty($hostobject->notes)) {

                                $name = strval($hostobject->host_name);
                                echo "<option value='" . $name . "' " . is_selected($host, $name) . ">$name</option>\n";
                            }
                        }
                    }
                ?>
            </select>

            <select name="hostgroup" id="reload_form_hostgroup" style="width: 150px;" class="form-control">

                <option value=""><?php echo _("Hostgroup"); ?>:</option>

                <?php
                    $args = array('orderby' => 'hostgroup_name:a');
                    $oxml = get_xml_hostgroup_objects($args);
                    if ($oxml) {
                        foreach ($oxml->hostgroup as $hg) {
                            $name = strval($hg->hostgroup_name);
                            echo "<option value='" . $name . "' " . is_selected($hostgroup, $name) . ">$name</option>\n";
                        }
                    }
                ?>
            </select>

            <input type="submit" name="reload_form_submit" id="reload_form_submit" value="Reload" />

            <br />
            
            <label style="font-weight: normal;">
                <input type="checkbox" id="hide_lines" name="hide_lines" <?php echo $hide_lines_checked; ?> value="1" />
                Hide Parent/Child Lines
            </label>
        </form>
    </div>

    </body>

    <script type="text/javascript">
        setTimeout(function() { document.getElementById('reload_form').submit(); }, <?php echo ($refresh * 1000); ?>);
    </script>
</html>

    <?php

    exit();
}


?>

